@@ -1,4 +1,7 @@
 #!/usr/bin/env python
+# Copyright (C) 2012-2021 jrnl contributors
+# License: https://www.gnu.org/licenses/gpl-3.0.html
+
 
 from datetime import datetime
 import logging
@@ -6,9 +9,9 @@ import os
 import re
 import sys
 
-from jrnl import Entry, time, util
-
-log = logging.getLogger(__name__)
+from . import Entry
+from . import time
+from .prompt import yesno
 
 
 class Tag:
@@ -56,7 +59,7 @@ class Journal:
         another journal object"""
         new_journal = cls(other.name, **other.config)
         new_journal.entries = other.entries
-        log.debug(
+        logging.debug(
             "Imported %d entries from %s to %s",
             len(new_journal),
             other.__class__.__name__,
@@ -85,7 +88,7 @@ class Journal:
         text = self._load(filename)
         self.entries = self._parse(text)
         self.sort()
-        log.debug("opened %s with %d entries", self.__class__.__name__, len(self))
+        logging.debug("opened %s with %d entries", self.__class__.__name__, len(self))
         return self
 
     def write(self, filename=None):
@@ -190,7 +193,6 @@ class Journal:
         end_date=None,
         starred=False,
         strict=False,
-        short=False,
         contains=None,
         exclude=[],
     ):
@@ -249,8 +251,9 @@ class Journal:
         to_delete = []
 
         def ask_delete(entry):
-            return util.yesno(
-                f"Delete entry '{entry.pprint(short=True)}'?", default=False,
+            return yesno(
+                f"Delete entry '{entry.pprint(short=True)}'?",
+                default=False,
             )
 
         for entry in self.entries:
@@ -280,7 +283,12 @@ class Journal:
                 if date:  # Parsed successfully, strip that from the raw text
                     starred = raw[:colon_pos].strip().endswith("*")
                     raw = raw[colon_pos + 1 :].strip()
-        starred = starred or first_line.startswith("*") or first_line.endswith("*")
+        starred = (
+            starred
+            or first_line.startswith("*")
+            or first_line.endswith("*")
+            or raw.startswith("*")
+        )
         if not date:  # Still nothing? Meh, just live in the moment.
             date = time.parse("now")
         entry = Entry.Entry(self, date, raw, starred=starred)
@@ -372,7 +380,7 @@ class LegacyJournal(Journal):
         return entries
 
 
-def open_journal(name, config, legacy=False):
+def open_journal(journal_name, config, legacy=False):
     """
     Creates a normal, encrypted or DayOne journal based on the passed config.
     If legacy is True, it will open Journals with legacy classes build for
@@ -395,11 +403,18 @@ def open_journal(name, config, legacy=False):
 
     if not config["encrypt"]:
         if legacy:
-            return LegacyJournal(name, **config).open()
-        return PlainJournal(name, **config).open()
-    else:
-        from . import EncryptedJournal
+            return LegacyJournal(journal_name, **config).open()
+        return PlainJournal(journal_name, **config).open()
 
+    from . import EncryptedJournal
+
+    try:
         if legacy:
-            return EncryptedJournal.LegacyEncryptedJournal(name, **config).open()
-        return EncryptedJournal.EncryptedJournal(name, **config).open()
+            return EncryptedJournal.LegacyEncryptedJournal(
+                journal_name, **config
+            ).open()
+        return EncryptedJournal.EncryptedJournal(journal_name, **config).open()
+    except KeyboardInterrupt:
+        # Since encrypted journals prompt for a password, it's easy for a user to ctrl+c out
+        print("[Interrupted while opening journal]", file=sys.stderr)
+        sys.exit(1)
