@@ -1,4 +1,7 @@
 #!/usr/bin/env python
+# Copyright (C) 2012-2021 jrnl contributors
+# License: https://www.gnu.org/licenses/gpl-3.0.html
+
 
 import glob
 import logging
@@ -8,12 +11,12 @@ import sys
 import xdg.BaseDirectory
 import yaml
 
-from . import __version__, util
-from .util import UserAbort, verify_config
-
-if "win32" not in sys.platform:
-    # readline is not included in Windows Active Python
-    import readline
+from . import __version__
+from .config import load_config
+from .config import verify_config_colors
+from .exception import UserAbort
+from .prompt import yesno
+from .upgrade import is_old_version
 
 DEFAULT_CONFIG_NAME = "jrnl.yaml"
 DEFAULT_JOURNAL_NAME = "journal.txt"
@@ -29,18 +32,6 @@ CONFIG_FILE_PATH_FALLBACK = os.path.join(USER_HOME, ".jrnl_config")
 JOURNAL_PATH = xdg.BaseDirectory.save_data_path(XDG_RESOURCE) or USER_HOME
 JOURNAL_FILE_PATH = os.path.join(JOURNAL_PATH, DEFAULT_JOURNAL_NAME)
 
-log = logging.getLogger(__name__)
-
-
-def module_exists(module_name):
-    """Checks if a module exists and can be imported"""
-    try:
-        __import__(module_name)
-    except ImportError:
-        return False
-    else:
-        return True
-
 
 default_config = {
     "version": __version__,
@@ -55,7 +46,12 @@ default_config = {
     "highlight": True,
     "linewrap": 79,
     "indent_character": "|",
-    "colors": {"date": "none", "title": "none", "body": "none", "tags": "none",},
+    "colors": {
+        "date": "none",
+        "title": "none",
+        "body": "none",
+        "tags": "none",
+    },
 }
 
 
@@ -93,10 +89,10 @@ def load_or_install_jrnl():
         else CONFIG_FILE_PATH_FALLBACK
     )
     if os.path.exists(config_path):
-        log.debug("Reading configuration from file %s", config_path)
-        config = util.load_config(config_path)
+        logging.debug("Reading configuration from file %s", config_path)
+        config = load_config(config_path)
 
-        if util.is_old_version(config_path):
+        if is_old_version(config_path):
             from . import upgrade
 
             try:
@@ -115,23 +111,21 @@ def load_or_install_jrnl():
                 sys.exit(1)
 
         upgrade_config(config)
-        verify_config(config)
+        verify_config_colors(config)
 
-        return config
     else:
-        log.debug("Configuration file not found, installing jrnl...")
+        logging.debug("Configuration file not found, installing jrnl...")
         try:
             config = install()
         except KeyboardInterrupt:
             raise UserAbort("Installation aborted")
-        return config
+
+    logging.debug('Using configuration "%s"', config)
+    return config
 
 
 def install():
-    if "win32" not in sys.platform:
-        readline.set_completer_delims(" \t\n;")
-        readline.parse_and_bind("tab: complete")
-        readline.set_completer(autocomplete)
+    _initialize_autocomplete()
 
     # Where to create the journal?
     path_query = f"Path to your journal file (leave blank for {JOURNAL_FILE_PATH}): "
@@ -148,7 +142,7 @@ def install():
         pass
 
     # Encrypt it?
-    encrypt = util.yesno(
+    encrypt = yesno(
         "Do you want to encrypt your journal? You can always change this later",
         default=False,
     )
@@ -160,7 +154,17 @@ def install():
     return default_config
 
 
-def autocomplete(text, state):
+def _initialize_autocomplete():
+    # readline is not included in Windows Active Python and perhaps some other distributions
+    if sys.modules.get("readline"):
+        import readline
+
+        readline.set_completer_delims(" \t\n;")
+        readline.parse_and_bind("tab: complete")
+        readline.set_completer(_autocomplete_path)
+
+
+def _autocomplete_path(text, state):
     expansions = glob.glob(os.path.expanduser(os.path.expandvars(text)) + "*")
     expansions = [e + "/" if os.path.isdir(e) else e for e in expansions]
     expansions.append(None)
